#!/bin/bash

set -o nounset
set -o xtrace

NUM_RETRIES=15
SLEEP_INTERVAL=30
GET_CERTIFICATES_API="https://trust-manager/api/v1/platform/trust-management/certificates"
ACCEPTED_ENTITIES="NSX_UA_TN, NSX_UA_EDGE, NSX_UA_SVM, SUBSCRIBER_NODE"
OUTPUT="/tmp/out.json"
TEMPDIR=$(mktemp -d)

date
echo "Start loading trusted certs..."

cp /certs-raw/* /certs

# create tls.key, tls.crt, ca.crt for calling trust manager API
openssl pkcs12 -in /certs-raw/truststore.p12 -cacerts -nokeys -out /tmp/ca.crt -password pass:"$CERTIFICATE_PASSWORD"
openssl pkcs12 -in /certs-raw/keystore.p12 -nokeys -out /tmp/tls.crt -password pass:"$CERTIFICATE_PASSWORD"
openssl pkcs12 -in /certs-raw/keystore.p12 -nodes -nocerts -out /tmp/tls.key -password pass:"$CERTIFICATE_PASSWORD"
ls /tmp/

# get certficates
n=0
while [ $n -lt $NUM_RETRIES ]; do
    status=$(curl -s -H 'Content-Type: application/json' -H 'x-nsx-roles: ZW50ZXJwcmlzZV9hZG1pbgo=' -o $OUTPUT $GET_CERTIFICATES_API -w "%{http_code}" \
        --cert /tmp/tls.crt --key /tmp/tls.key --cacert /tmp/ca.crt)
    if [ "$status" -eq 200 ] && [ "$status" -ne 202 ]; then
        cat $OUTPUT
        break
    fi
    echo "Try #$n: get certificates, but get status code $status"
    n=$((n + 1))
    sleep $SLEEP_INTERVAL
done

if [ $n -eq $NUM_RETRIES ]; then
    echo "All attempts failed"
    exit 1
fi

# write each certificate into a file
pushd "$TEMPDIR"
cat "$OUTPUT" | jq --arg ALLOW "$ACCEPTED_ENTITIES" '.results[] | select(.used_by | inside($ALLOW)) | "echo -e \(.pem_encoded|@sh) > \(.uuid|@sh)" ' | xargs -r -n 1 bash -c
popd

if [ "$(ls -A $TEMPDIR)" ]; then
    # split it in case it contains chained certificates
    for file in $TEMPDIR/*; do
        uuid=$(basename "$file")
        cat $file | csplit -s -z -f $TEMPDIR/$uuid- - '/-----BEGIN CERTIFICATE-----/' '{*}'
        rm "$file"
    done

    # import each certificate into truststore
    for file in $TEMPDIR/*; do
        uuid=$(basename "$file")
        echo "Import $uuid"
        keytool -importcert -noprompt -keystore /certs/truststore.p12 -storepass "$CERTIFICATE_PASSWORD" -alias "$uuid" -file "$file" -storetype PKCS12
    done
else
    echo "No accepted certificates"
    exit 0
fi

date
echo "Done loading trusted certs..."
