# Values to be rendered: .Release.Namespace
SVC_NAME="${MY_POD_NAME}-external"

# Auxiliar functions
retry_while() {
    local -r cmd="${1:?cmd is missing}"
    local -r retries="${2:-12}"
    local -r sleep_time="${3:-5}"
    local return_value=1
    read -r -a command <<<"$cmd"
    for ((i = 1; i <= retries; i += 1)); do
        "${command[@]}" && return_value=0 && break
        sleep "$sleep_time"
    done
    return $return_value
}

k8s_svc_lb_ip() {
    local namespace=${1:?namespace is missing}
    local service=${2:?service is missing}
    local service_ip=$(kubectl get svc "$service" -n "$namespace" -o jsonpath="{.status.loadBalancer.ingress[0].ip}")
    local service_hostname=$(kubectl get svc "$service" -n "$namespace" -o jsonpath="{.status.loadBalancer.ingress[0].hostname}")
    if [[ -n ${service_ip} ]]; then
        echo "${service_ip}"
    else
        echo "${service_hostname}"
    fi
}

k8s_svc_lb_ip_ready() {
    local namespace=${1:?namespace is missing}
    local service=${2:?service is missing}
    [[ -n "$(k8s_svc_lb_ip "$namespace" "$service")" ]]
}

k8s_svc_lb_port() {
    local namespace=${1:?namespace is missing}
    local service=${2:?service is missing}
    local index=${3:-0}
    local node_port="$(kubectl get svc "$service" -n "$namespace" -o jsonpath="{.spec.ports[$index].port}")"
    echo "$node_port"
}

date
echo "Waiting until LoadBalancer IP is ready"
# Wait until LoadBalancer IP is ready
retry_while "k8s_svc_lb_ip_ready {{ .Release.Namespace }} $SVC_NAME" || exit 1
# Obtain LoadBalancer external IP
EXTERNAL_ACCESS_IP=$(k8s_svc_lb_ip "{{ .Release.Namespace }}" "$SVC_NAME")
EXTERNAL_ACCESS_PORT=$(k8s_svc_lb_port "{{ .Release.Namespace }}" "$SVC_NAME")
date
echo "LoadBalancer IP is ready..."
