# Constants


class Certificate:
    service_type = "K8S_MSG_CLIENT"
    # k8s_msg_client certificate attributes
    display_name = "message bus client for NSX Application platform"
    algorithm = "RSA"
    key_size = "2048"
    subject = {
        "attributes": [
            {"key": "CN", "value": "k8s-msg-client"},
            {"key": "O", "value": "VMware Inc."},
            {"key": "OU", "value": "NSX"},
            {"key": "L", "value": "Palo Alto"},
            {"key": "ST", "value": "CA"},
            {"key": "C", "value": "US"},
        ]
    }


# PORTs
PRTON_PORT = 7440


# API URIs on manager side
GET_CLUSTER_CERT = "/nsxapi/api/v1/trust-management/certificates?details" \
                   "=true&&type=cluster_api_certificate"
GET_CLUSTER_CERT_WITH_PRIVATE_KEY = "/nsxapi/api/v1/trust-management" \
                                    "/certificates/<id>?action=get_private"
GET_ALL_CERTS = "/nsxapi/api/v1/trust-management/certificates"
GET_PI_CERTS = "/nsxapi/api/v1/trust-management/principal-identities"
DELETE_PI = "/nsxapi/api/v1/trust-management/principal-identities/<id>"
DELETE_CERT = "/nsxapi/api/v1/trust-management/certificates/<id>"
POST_REGISTER_PI_CERT = "/nsxapi/api/v1/trust-management/" \
                        "principal-identities/with-certificate"
POST_APPLY_KAFKA_CLIENT_CERT = "/nsxapi/api/v1/trust-management/certificates" \
                               "/<id>?action=apply_certificate&service_type" \
                               "=K8S_MSG_CLIENT"
RELEASE_USED_CERTIFICATE = "/nsxapi/api/v1/trust-management/certificates/<id" \
                           ">?action=release"
POST_GENERATE_CSR = "/nsxapi/api/v1/trust-management/csrs"
POST_SELF_SIGN_CSR = "/nsxapi/api/v1/trust-management/csrs/<id>?action" \
                     "=self_sign&days_valid=3650"
DELETE_CSR = "/nsxapi/api/v1/trust-management/csrs/<id>"

# API URIs on cloud native platform side
GET_CLOUDNATIVE_PLATFORM_CERTS = "/napp/api/v1/platform/trust" \
                                 "-management/certificates"
POST_CLOUDNATIVE_PLATFROM_CERT = "/napp/api/v1/platform/trust" \
                                 "-management/certificates"
GET_PLATFORM_HEALTH = "/napp/api/v1/platform/monitor/platform/status"
GET_FEATURES_INTELLIGENCE_CONFIG = "/napp/api/v1/platform/features" \
                                   "/intelligence/config"
NAPP_CERT_EGRESS_ENTITIES = {"NAPP_PLATFORM_EGRESS"}
NAPP_CERT_NONEGRESS_ENTITIES = {"NAPP_PLATFORM_INGRESS",
                                "NAPP_PLATFORM_KAFKA"}

# FILE PATHs
WORK_DIR = "./tmp/"
PRIVATE_KEY_PATH = WORK_DIR + "tls.key"
PUBLIC_CERT_PATH = WORK_DIR + "tls.crt"
NAPP_PLATFORM_CA_PATH = WORK_DIR + "ca.crt"

#NSX Compatibilty file name
COMPATIBILITY_FILE = 'nsx-platform-compatibility.cfg'

# HELM CA Certificates Constants
PATH_CA_CERTIFICATE_DIR = "/usr/local/share/ca-certificates"
YAML_SECRET_HARBOR = """
apiVersion: v1
kind: Secret
metadata:
  name: harbor-certs
type: Opaque
data:
"""
YAML_VOLUME_DEFINITION = """
name: replace_me
secret:
  secretName: harbor-certs
  defaultMode: 420
  items:
    - key: replace_me
      path: replace_me.pem
"""
YAML_VOLUME_MOUNT = """
name: replace_me
mountPath: /etc/ssl/certs/replace_me.pem
subPath: replace_me.pem
"""
YAML_DEPLOYMENT_PATCH = """
spec:
  template:
    spec:
      containers:
        - name: cluster-api
      volumes:
"""
