SELECT 'CREATE DATABASE malwareprevention' WHERE NOT EXISTS (SELECT FROM pg_database WHERE datname = 'malwareprevention')\gexec
\c malwareprevention

CREATE TABLE IF NOT EXISTS sa_configurations (
    key CHAR(100) NOT NULL,
    value TEXT
);

CREATE TABLE IF NOT EXISTS public."allow_list_table"
(
    sha256 character(64) COLLATE pg_catalog."default" NOT NULL,
    sha1 character(40) COLLATE pg_catalog."default",
    md5 character(32) COLLATE pg_catalog."default",
    PRIMARY KEY(sha256)
);

CREATE SEQUENCE IF NOT EXISTS public.inspection_events_id_seq
    INCREMENT 1
    START 1
    MINVALUE 1
    MAXVALUE 9223372036854775807
    CACHE 1;

CREATE TABLE IF NOT EXISTS public.inspection_events
(
    id bigint NOT NULL DEFAULT nextval('inspection_events_id_seq'::regclass),
    sha256 character(64) COLLATE pg_catalog."default",
    sha1 character(40) COLLATE pg_catalog."default",
    md5 character(32) COLLATE pg_catalog."default",
    file_name character varying(256) COLLATE pg_catalog."default",
    file_type character varying(128) COLLATE pg_catalog."default",
    file_size bigint,
    start_time bigint,
    end_time bigint,
    inspection_time bigint,
    client_port integer,
    client_ip character varying(40) COLLATE pg_catalog."default",
    client_fqdn character varying(256) COLLATE pg_catalog."default",
    client_vm_id character varying(128) COLLATE pg_catalog."default",
    server_port integer,
    server_ip character varying(40) COLLATE pg_catalog."default",
    server_fqdn character varying(256) COLLATE pg_catalog."default",
    server_vm_id character varying(128) COLLATE pg_catalog."default",
    application_protocol character varying(50) COLLATE pg_catalog."default",
    submitted_by character varying(30) COLLATE pg_catalog."default",
    is_found_by_asds boolean,
    is_blocked boolean,
    is_allow_listed boolean,
    is_file_upload boolean,
    verdict character varying(14) COLLATE pg_catalog."default",
    score smallint,
    analyst_uuid character varying(256) COLLATE pg_catalog."default",
    submission_uuid character varying(256) COLLATE pg_catalog."default",
    tn_id character varying(48) COLLATE pg_catalog."default",
    malware_class character varying(1024) COLLATE pg_catalog."default",
    malware_family character varying(1024) COLLATE pg_catalog."default",
    node_type integer,
    gateway_id character varying(48) COLLATE pg_catalog."default",
    error_code character varying(32) COLLATE pg_catalog."default",
    error_message character varying(1024) COLLATE pg_catalog."default",
    analysis_status character varying(32) COLLATE pg_catalog."default",
    is_follow_up_event boolean,
    CONSTRAINT inspection_events_pkey PRIMARY KEY (id)
);

CREATE INDEX inspection_events_ordered_inspection_time_sha_idx
    ON public.inspection_events USING btree
    (inspection_time DESC NULLS LAST, sha256 COLLATE pg_catalog."default" ASC NULLS LAST);

CREATE INDEX inspection_events_sha256_idx
    ON public.inspection_events USING btree
    (sha256 COLLATE pg_catalog."default" ASC NULLS LAST);

CREATE INDEX inspection_events_inspection_time_idx
    ON public.inspection_events USING btree
    (inspection_time DESC NULLS LAST);

CREATE INDEX inspection_events_submission_uuid_idx
    ON public.inspection_events USING hash
    (submission_uuid COLLATE pg_catalog."default")
    where submission_uuid is not null;

CREATE UNIQUE INDEX inspection_event_unique_idx
    ON public.inspection_events (sha256, inspection_time, tn_id);

CREATE TABLE IF NOT EXISTS public.http_header
(
    event_id bigint NOT NULL,
    http_method character varying(20) COLLATE pg_catalog."default",
    http_domain character varying(256) COLLATE pg_catalog."default",
    http_path character varying(256) COLLATE pg_catalog."default",
    http_user_agent character varying(1024) COLLATE pg_catalog."default",
    http_referer character varying(1024) COLLATE pg_catalog."default",
    content_disposition_file_name character varying(256) COLLATE pg_catalog."default",
    CONSTRAINT event_id_fk FOREIGN KEY (event_id)
        REFERENCES public.inspection_events (id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE CASCADE
        NOT VALID
);

CREATE UNIQUE INDEX http_header_unique_idx
    ON public.http_header (event_id);

CREATE TABLE IF NOT EXISTS public."intercepted_entities"
(
    sha256 character(64) COLLATE pg_catalog."default" NOT NULL,
    verdict_source integer,
    sha1 character(40) COLLATE pg_catalog."default",
    md5 character(32) COLLATE pg_catalog."default",
    file_name character varying(256) COLLATE pg_catalog."default",
    file_type character varying(128) COLLATE pg_catalog."default",
    analyst_uuid character varying(256) COLLATE pg_catalog."default",
    verdict character varying(14) COLLATE pg_catalog."default",
    malware_category character varying(128) COLLATE pg_catalog."default",
    malware_group character varying(32) COLLATE pg_catalog."default",
    malware_family character varying(1024) COLLATE pg_catalog."default",
    malware_class character varying(1024) COLLATE pg_catalog."default",
    reputation_confidence integer,
    publisher_name character varying(256) COLLATE pg_catalog."default",
    publisher_signature_status character varying(256) COLLATE pg_catalog."default",
    publisher_signature_verified boolean,
    publisher_signature_signed_by character varying(256) COLLATE pg_catalog."default",
    score smallint,
    ttl bigint,
    last_updated bigint,
    PRIMARY KEY(sha256, verdict_source)
);

CREATE INDEX intercepted_entities_sha256_idx
    ON public.intercepted_entities USING btree
    (sha256);

CREATE INDEX intercepted_entites_analyst_uuid_idx
    ON public.intercepted_entities USING hash
    (analyst_uuid COLLATE pg_catalog."default")
    where analyst_uuid is not null;

CREATE TABLE IF NOT EXISTS public."reputation_cloud_service_config"
(
    client_id character varying(36) COLLATE pg_catalog."default",
    encrypted_client_secret character varying(512) COLLATE pg_catalog."default",
    UNIQUE (client_id)
);

CREATE TABLE IF NOT EXISTS public."reputation_query_metadata"
(
    sha256 character(64) COLLATE pg_catalog."default" NOT NULL,
    last_queried_time timestamp without time zone NOT NULL,
    query_count integer NOT NULL,
    status character(32) COLLATE pg_catalog."default" NOT NULL,
    CONSTRAINT reputation_query_metadata_pkey PRIMARY KEY (sha256)
);

CREATE TABLE IF NOT EXISTS public."unavailable_queue_table"
(
    sha256 character(64) COLLATE pg_catalog."default" NOT NULL,
    last_updated_time timestamp without time zone,
    status character varying(32) COLLATE pg_catalog."default",
    UNIQUE (sha256)
);

CREATE INDEX unavailable_queue_table_idx
    ON public.unavailable_queue_table USING btree
    (sha256);

CREATE TABLE IF NOT EXISTS public."update_queue"
(
    sha256 character(64) COLLATE pg_catalog."default" NOT NULL,
    last_updated_time timestamp without time zone,
    status character varying(32) COLLATE pg_catalog."default",
    UNIQUE (sha256)
);

CREATE INDEX update_queue_idx
    ON public.update_queue USING btree
    (sha256);

CREATE TABLE IF NOT EXISTS public."reputation_update_marker"
(
    id integer PRIMARY KEY,
    cursor character varying(512) COLLATE pg_catalog."default",
    status character varying(32) NOT NULL COLLATE pg_catalog."default",
    last_update_timestamp timestamp without time zone
);

INSERT INTO public."reputation_update_marker" (id, status) VALUES (1, 'COMPLETE') ON CONFLICT DO NOTHING;

CREATE TABLE IF NOT EXISTS public."reputation_pubsub_config"
(
    subscription_id character varying(64) COLLATE pg_catalog."default",
    subscriber_name character varying(64) COLLATE pg_catalog."default",
    message_type character varying(16) COLLATE pg_catalog."default",
    kafka_topic character varying(64) COLLATE pg_catalog."default",
    subscription_state character varying(16) COLLATE pg_catalog."default"
);

CREATE TABLE IF NOT EXISTS public."reputation_failed_hash"
(
    sha256 character(64) COLLATE pg_catalog."default" NOT NULL,
    last_retry_time timestamp without time zone NOT NULL,
    next_retry_time timestamp without time zone NOT NULL,
    retry_count integer NOT NULL,
    CONSTRAINT reputation_failed_hash_pkey PRIMARY KEY (sha256)
);

CREATE TABLE IF NOT EXISTS public."non_benign_table"
(
    sha256 character(64) COLLATE pg_catalog."default",
    sha1 character(40) COLLATE pg_catalog."default",
    md5 character(32) COLLATE pg_catalog."default",
    file_name character varying(256) COLLATE pg_catalog."default",
    file_type character varying(128) COLLATE pg_catalog."default",
    file_size bigint,
    start_time bigint,
    end_time bigint,
    inspection_time bigint,
    client_port integer,
    client_ip character varying(40) COLLATE pg_catalog."default",
    client_fqdn character varying(256) COLLATE pg_catalog."default",
    client_vm_id character varying(128) COLLATE pg_catalog."default",
    server_port integer,
    server_ip character varying(40) COLLATE pg_catalog."default",
    server_fqdn character varying(256) COLLATE pg_catalog."default",
    server_vm_id character varying(128) COLLATE pg_catalog."default",
    application_protocol character varying(50) COLLATE pg_catalog."default",
    submitted_by character varying(30) COLLATE pg_catalog."default",
    is_found_by_asds boolean,
    is_blocked boolean,
    is_allow_listed boolean,
    is_file_upload boolean,
    verdict character varying(14) COLLATE pg_catalog."default",
    score smallint,
    analyst_uuid character varying(256) COLLATE pg_catalog."default",
    submission_uuid character varying(256) COLLATE pg_catalog."default",
    tn_id character varying(48) COLLATE pg_catalog."default",
    malware_class character varying(1024) COLLATE pg_catalog."default",
    malware_family character varying(1024) COLLATE pg_catalog."default",
    node_type integer,
    gateway_id character varying(48) COLLATE pg_catalog."default",
    error_code character varying(32) COLLATE pg_catalog."default",
    error_message character varying(1024) COLLATE pg_catalog."default",
    analysis_status character varying(32) COLLATE pg_catalog."default",
    is_follow_up_event boolean
);

CREATE TABLE IF NOT EXISTS public."summary_table"
(
    inspection_time bigint,
    local_inspection_count bigint,
    cloud_inspection_count bigint,
    score_0_10_count bigint,
    score_11_20_count bigint,
    score_21_30_count bigint,
    CONSTRAINT summary_table_pkey PRIMARY KEY (inspection_time)
);

DROP TYPE IF EXISTS public.event_trend;
CREATE TYPE public.event_trend AS
(
    inspection_time bigint,
    score smallint,
    is_allow_listed boolean
);

CREATE INDEX non_benign_table_ordered_inspection_time_sha_idx
    ON public.non_benign_table USING btree
    (inspection_time DESC NULLS LAST, sha256 COLLATE pg_catalog."default" ASC NULLS LAST);

CREATE INDEX non_benign_table_inspection_events_sha256_idx
    ON public.non_benign_table USING btree
    (sha256 COLLATE pg_catalog."default" ASC NULLS LAST);

CREATE INDEX non_benign_table_inspection_events_inspection_time_idx
    ON public.non_benign_table USING btree
    (inspection_time DESC NULLS LAST);

CREATE TABLE IF NOT EXISTS public.client_cache_mapping
(
    sha256 character(64) COLLATE pg_catalog."default",
    tn_id  character varying(48) COLLATE pg_catalog."default",
    score smallint,
    verdict character varying(32) COLLATE pg_catalog."default",
    inspection_time bigint,
    ttl bigint,
    file_type character varying(128) COLLATE pg_catalog."default",
    is_allow_listed boolean
);

CREATE TABLE IF NOT EXISTS public.kafka_offset
(
    topic character(64) COLLATE pg_catalog."default",
    partition integer,
    committed_offset bigint,
    CONSTRAINT kafka_offset_pkey PRIMARY KEY (topic, partition)
);

CREATE TABLE IF NOT EXISTS public.malware_class
(
    malware_class_name character varying(128) COLLATE pg_catalog."default",
    inspection_time bigint,
    CONSTRAINT malware_class_pkey PRIMARY KEY (malware_class_name)
);

CREATE TABLE IF NOT EXISTS public.malware_family
(
    malware_family_name character varying(128) COLLATE pg_catalog."default",
    inspection_time bigint,
    CONSTRAINT malware_family_pkey PRIMARY KEY (malware_family_name)
);


\c postgres
